@@ -1,7 +1,7 @@
 from .payload import BroadcastPayload
 from .request import BroadcastRequest
 from .response import BroadcastResponse
-from .result import BroadcastResult
+from .result import BroadcastResult, RawBroadcastResult
 from .service import BroadcastService
 from .status import BroadcastStatus
 
@@ -10,6 +10,7 @@ __all__ = [
   'BroadcastRequest',
   'BroadcastResponse',
   'BroadcastResult',
+  'RawBroadcastResult',
   'BroadcastService',
   'BroadcastStatus',
 ]
