@@ -8,8 +8,8 @@ class BroadcastStatus(StrEnum):
   """Broadcast result status"""
 
   OK = 'OK'
-  BADREQUEST = 'BADREQUEST'
-  INTERNALERROR = 'INTERNALERROR'
+  BAD_REQUEST = 'BADREQUEST'
+  INTERNAL_ERROR = 'INTERNALERROR'
   UNAUTHORIZED = 'UNAUTHORIZED'
   UNPROCESSABLE = 'UNPROCESSABLE'
   DISCONNECTED = 'DISCONNECTED'
