@@ -1,6 +1,8 @@
 """Device entitiy"""
 
-from pydantic import BaseModel, Field
+from typing import Any
+
+from pydantic import BaseModel, Field, field_validator
 
 from .modbus import ModbusConfig
 
@@ -18,4 +20,13 @@ class Device(BaseModel):
   protocol: str = Field(description='Defines the protocol of the device')
   is_primary: bool = Field(default=False, description='Defines if the device is the primary device')
 
+  @field_validator('is_primary', mode='before')
+  def validate_is_primary(cls, value: Any) -> bool:
+    """Validate that is_primary is a boolean value."""
+    if isinstance(value, str):
+      return value.lower() in ('true', '1', 'yes')
+    if isinstance(value, bool):
+      return value
+    return False
+
   modbus: ModbusConfig | None = Field(default=None, description='Modbus configuration')
