@@ -1,15 +1,10 @@
 """Http Operation Type"""
 
-import sys
-from enum import Enum
-
-if sys.version_info >= (3, 11):
-  from typing import Self
-else:
-  from typing_extensions import Self
+from enum import StrEnum
+from typing import Self
 
 
-class HttpRequestType(str, Enum):
+class HttpRequestType(StrEnum):
   """
   Http Operation Type definition
   """
